@@ -64,6 +64,11 @@ class ConnectionProfilesClient:
         args.postgresql_client_key, 'Postgresql client private key'
     )
 
+    # Validation for Oracle SSL config fields.
+    self._ValidateCertificateFormat(
+        args.oracle_ca_certificate, 'Oracle CA certificate'
+    )
+
   def _ValidateCertificateFormat(self, certificate, name):
     if not certificate:
       return True
@@ -93,13 +98,22 @@ class ConnectionProfilesClient:
         sslConfig=ssl_config)
 
   def _GetOracleProfile(self, args):
+    ssl_config = self._GetOracleSslConfig(args)
     return self._messages.OracleProfile(
         hostname=args.oracle_hostname,
         port=args.oracle_port,
         username=args.oracle_username,
         password=args.oracle_password,
         secretManagerStoredPassword=args.oracle_secret_manager_stored_password,
-        databaseService=args.database_service)
+        databaseService=args.database_service,
+        oracleSslConfig=ssl_config)
+
+  def _GetOracleSslConfig(self, args):
+    """Returns a OracleSslConfig message based on the given args."""
+    return self._messages.OracleSslConfig(
+        caCertificate=args.oracle_ca_certificate,
+        serverCertificateDistinguishedName=args.oracle_server_certificate_distinguished_name,
+    )
 
   def _GetPostgresqlSslConfig(self, args):
     """Returns a PostgresqlSslConfig message based on the given args."""
@@ -109,13 +123,17 @@ class ConnectionProfilesClient:
               clientCertificate=args.postgresql_client_certificate,
               clientKey=args.postgresql_client_key,
               caCertificate=args.postgresql_ca_certificate,
-          ))
+              serverCertificateHostname=args.postgresql_server_certificate_hostname,
+          )
+      )
 
     if args.postgresql_ca_certificate:
       return self._messages.PostgresqlSslConfig(
           serverVerification=self._messages.ServerVerification(
               caCertificate=args.postgresql_ca_certificate,
-          ))
+              serverCertificateHostname=args.postgresql_server_certificate_hostname,
+          )
+      )
 
     return None
 
@@ -177,12 +195,17 @@ class ConnectionProfilesClient:
     """Returns the MongoDB profile message based on the given args."""
     addresses = []
     for host_address in args.mongodb_host_addresses:
-      hostport = HostPort.Parse(host_address)
-      addresses.append(
-          self._messages.HostAddress(
-              hostname=hostport.host, port=int(hostport.port)
-          )
-      )
+      if args.mongodb_srv_connection_format:
+        addresses.append(
+            self._messages.HostAddress(hostname=host_address)
+        )
+      else:
+        hostport = HostPort.Parse(host_address)
+        addresses.append(
+            self._messages.HostAddress(
+                hostname=hostport.host, port=int(hostport.port)
+            )
+        )
     profile = self._messages.MongodbProfile(
         hostAddresses=addresses,
         username=args.mongodb_username,
@@ -190,10 +213,25 @@ class ConnectionProfilesClient:
         password=args.mongodb_password,
         secretManagerStoredPassword=args.mongodb_secret_manager_stored_password,
     )
+    if (
+        args.mongodb_direct_connection
+        and not args.mongodb_standard_connection_format
+    ):
+      raise exceptions.InvalidArgumentException(
+          'mongodb-direct-connection',
+          'mongodb direct connection can only be used with the standard'
+          ' connection format.',
+      )
     if args.mongodb_srv_connection_format:
       profile.srvConnectionFormat = {}
     if args.mongodb_standard_connection_format:
-      profile.standardConnectionFormat = {}
+      profile.standardConnectionFormat = (
+          self._messages.StandardConnectionFormat(
+              directConnection=args.mongodb_direct_connection
+          )
+      )
+    if args.mongodb_tls:
+      profile.sslConfig = {}
     return profile
 
   def _ParseSslConfig(self, data):
@@ -524,6 +562,23 @@ class ConnectionProfilesClient:
         update_fields.append(
             'postgresqlProfile.sslConfig.serverVerification.caCertificate'
         )
+    if args.IsSpecified('postgresql_server_certificate_hostname'):
+      if (
+          connection_profile.postgresqlProfile.sslConfig.serverAndClientVerification
+      ):
+        connection_profile.postgresqlProfile.sslConfig.serverAndClientVerification.serverCertificateHostname = (
+            args.postgresql_server_certificate_hostname
+        )
+        update_fields.append(
+            'postgresqlProfile.sslConfig.serverAndClientVerification.serverCertificateHostname'
+        )
+      else:
+        connection_profile.postgresqlProfile.sslConfig.serverVerification.serverCertificateHostname = (
+            args.postgresql_server_certificate_hostname
+        )
+        update_fields.append(
+            'postgresqlProfile.sslConfig.serverVerification.serverCertificateHostname'
+        )
 
   def _UpdatePostgresqlProfile(self, connection_profile, args, update_fields):
     """Updates Postgresql connection profile."""
@@ -639,10 +694,15 @@ class ConnectionProfilesClient:
     if args.IsSpecified('mongodb_host_addresses'):
       addresses = []
       for host_address in args.mongodb_host_addresses:
-        hostname, port = host_address.split(':')
-        addresses.append(
-            self._messages.HostAddress(hostname=hostname, port=int(port))
-        )
+        if args.mongodb_srv_connection_format:
+          addresses.append(
+              self._messages.HostAddress(hostname=host_address)
+          )
+        else:
+          hostname, port = host_address.split(':')
+          addresses.append(
+              self._messages.HostAddress(hostname=hostname, port=int(port))
+          )
       connection_profile.mongodbProfile.hostAddresses = addresses
       update_fields.append('monogodbProfile.hostAddresses')
     if args.IsSpecified('mongodb_replica_set'):
