@@ -26,9 +26,11 @@ from typing import Any
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
+from googlecloudsdk.calliope import parser_arguments
 from googlecloudsdk.command_lib.compute import flags as compute_flags
 from googlecloudsdk.command_lib.util.apis import arg_utils
 
+
 INSTANCE_TEMPLATE_ARG = compute_flags.ResourceArgument(
     '--template',
     resource_name='instance template',
@@ -617,6 +619,8 @@ def AddMigForceUpdateOnRepairFlags(parser):
 def AddMigDefaultActionOnVmFailure(parser, release_track):
   if release_track == base.ReleaseTrack.ALPHA:
     AddMigDefaultActionOnVmFailureAlpha(parser)
+  elif release_track == base.ReleaseTrack.BETA:
+    AddMigDefaultActionOnVmFailureBeta(parser)
   else:
     AddMigDefaultActionOnVmFailureGA(parser)
 
@@ -642,6 +646,30 @@ def AddMigDefaultActionOnVmFailureGA(parser):
   )
 
 
+def AddMigDefaultActionOnVmFailureBeta(parser):
+  """Add default action on VM failure to the parser."""
+  help_text = """\
+      Specifies the action that a MIG performs on a failed VM. If the value of
+      the onFailedHealthCheck field is `DEFAULT_ACTION`, then the same action
+      also applies to the VMs on which your application fails a health check.
+      By default, the value of the flag is set to ``repair''."""
+  choices = collections.OrderedDict([
+      (
+          'repair',
+          '(Default) MIG automatically repairs a failed VM by recreating it.',
+      ),
+      ('do-nothing', 'MIG does not repair a failed VM.'),
+  ])
+
+  parser.add_argument(
+      '--default-action-on-vm-failure',
+      metavar='ACTION_ON_VM_FAILURE',
+      type=arg_utils.EnumNameToChoice,
+      choices=choices,
+      help=help_text,
+  )
+
+
 def AddMigDefaultActionOnVmFailureAlpha(parser):
   """Add default action on VM failure to the parser."""
   help_text = """\
@@ -837,6 +865,38 @@ def AddTargetSizePolicyModeFlag(parser):
   )
 
 
+def AddWorkloadPolicyFlag(parser: parser_arguments.ArgumentInterceptor):
+  """Add workload policy flag."""
+  parser.add_argument(
+      '--workload-policy',
+      type=str,
+      metavar='WORKLOAD_POLICY',
+      help=(
+          'Specifies the workload policy for the managed instance group. It '
+          'can be a full or partial URL to a resource policy containing '
+          'the workload policy.'
+      ),
+  )
+
+
+def AddRemoveWorkloadPolicyFlag(parser: parser_arguments.ArgumentInterceptor):
+  """Add remove workload policy flag."""
+  parser.add_argument(
+      '--remove-workload-policy',
+      action='store_true',
+      help=(
+          'Detaches the workload policy from the managed instance group.'
+      ),
+  )
+
+
+def AddWorkloadPolicyFlags(parser: parser_arguments.ArgumentInterceptor):
+  """Add flags for managing workload policy."""
+  workload_policy_group = parser.add_group(mutex=True)
+  AddWorkloadPolicyFlag(workload_policy_group)
+  AddRemoveWorkloadPolicyFlag(workload_policy_group)
+
+
 class ArgMultiValueDict:
   """Converts argument values into multi-valued mappings.
 
