@@ -41,7 +41,7 @@ from googlecloudsdk.command_lib.storage.tasks.cp import copy_util
 from googlecloudsdk.command_lib.storage.tasks.cp import download_util
 from googlecloudsdk.command_lib.storage.tasks.cp import file_part_download_task
 from googlecloudsdk.command_lib.storage.tasks.cp import finalize_sliced_download_task
-from googlecloudsdk.command_lib.storage.tasks.rm import delete_object_task
+from googlecloudsdk.command_lib.storage.tasks.rm import delete_task
 from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.util import scaled_integer
@@ -62,7 +62,6 @@ def _should_perform_sliced_download(source_resource, destination_resource):
       properties.VALUES.storage.sliced_object_download_threshold.Get())
   component_size = scaled_integer.ParseInteger(
       properties.VALUES.storage.sliced_object_download_component_size.Get())
-  # TODO(b/183017513): Only perform sliced downloads with parallelism.
   api_capabilities = api_factory.get_capabilities(
       source_resource.storage_url.scheme)
   return (source_resource.size and threshold != 0 and
@@ -71,7 +70,7 @@ def _should_perform_sliced_download(source_resource, destination_resource):
           task_util.should_use_parallelism())
 
 
-class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
+class FileDownloadTask(copy_util.ObjectCopyTaskWithExitHandler):
   """Represents a command operation triggering a file download."""
 
   def __init__(
@@ -100,27 +99,24 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
         object afterwards.
       do_not_decompress (bool): Prevents automatically decompressing downloaded
         gzips.
-      posix_to_set (PosixAttributes|None): Set as local POSIX attributes on
-        target.
-      print_created_message (bool): Print a message containing the versioned URL
-        of the copy result.
-      print_source_version (bool): Print source object version in status message
-        enabled by the `verbose` kwarg.
+      posix_to_set (PosixAttributes|None): See parent class.
+      print_created_message (bool): See parent class.
+      print_source_version (bool): See parent class.
       system_posix_data (SystemPosixData): System-wide POSIX info.
-      user_request_args (UserRequestArgs|None): Values for RequestConfig.
-      verbose (bool): Print a "copying" status message on initialization.
+      user_request_args (UserRequestArgs|None): See parent class..
+      verbose (bool): See parent class.
     """
     super(FileDownloadTask, self).__init__(
         source_resource,
         destination_resource,
         posix_to_set=posix_to_set,
+        print_created_message=print_created_message,
         print_source_version=print_source_version,
         user_request_args=user_request_args,
         verbose=verbose,
     )
     self._delete_source = delete_source
     self._do_not_decompress = do_not_decompress
-    self._print_created_message = print_created_message
     self._system_posix_data = system_posix_data
 
     self._temporary_destination_resource = (
@@ -138,7 +134,7 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
 
   def _get_temporary_destination_resource(self):
     temporary_resource = copy.deepcopy(self._destination_resource)
-    temporary_resource.storage_url.object_name += (
+    temporary_resource.storage_url.resource_name += (
         storage_url.TEMPORARY_FILE_SUFFIX)
     return temporary_resource
 
@@ -186,7 +182,7 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
     log.status.Print('Temporary download file corrupt.'
                      ' Restarting download {}'.format(self._source_resource))
     temporary_download_url = self._temporary_destination_resource.storage_url
-    os.remove(temporary_download_url.object_name)
+    os.remove(temporary_download_url.resource_name)
     tracker_file_util.delete_download_tracker_files(temporary_download_url)
 
   def execute(self, task_status_queue=None):
@@ -209,7 +205,7 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
     # more information: https://github.com/GoogleCloudPlatform/gsutil/pull/1202.
     # Note that it's not enough to check the results of `exists()`, since that
     # method returns False if the path points to a broken symlink.
-    is_destination_symlink = os.path.islink(destination_url.object_name)
+    is_destination_symlink = os.path.islink(destination_url.resource_name)
     if is_destination_symlink or destination_url.exists():
       if self._user_request_args and self._user_request_args.no_clobber:
         log.status.Print(copy_util.get_no_clobber_message(destination_url))
@@ -219,12 +215,12 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
               self._destination_resource,
               copy_util.get_no_clobber_message(destination_url))
         return
-      os.remove(destination_url.object_name)
+      os.remove(destination_url.resource_name)
 
     temporary_download_file_exists = (
         self._temporary_destination_resource.storage_url.exists())
     if temporary_download_file_exists and os.path.getsize(
-        self._temporary_destination_resource.storage_url.object_name
+        self._temporary_destination_resource.storage_url.resource_name
     ) > self._source_resource.size:
       self._restart_download()
 
@@ -280,8 +276,8 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
     )
     download_util.finalize_download(
         self._source_resource,
-        temporary_file_url.object_name,
-        destination_url.object_name,
+        temporary_file_url.resource_name,
+        destination_url.resource_name,
         convert_symlinks=preserve_symlinks,
         do_not_decompress_flag=self._do_not_decompress,
         server_encoding=server_encoding,
@@ -302,8 +298,7 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
         preserve_symlinks=preserve_symlinks,
     )
 
-    if self._print_created_message:
-      log.status.Print('Created: {}'.format(destination_url))
+    self._print_created_message_if_requested(self._destination_resource)
     if self._send_manifest_messages:
       manifest_util.send_success_message(
           task_status_queue,
@@ -315,7 +310,7 @@ class FileDownloadTask(copy_util.CopyTaskWithExitHandler):
     if self._delete_source:
       return task.Output(
           additional_task_iterators=[[
-              delete_object_task.DeleteObjectTask(
-                  self._source_resource.storage_url),
+              delete_task.DeleteObjectTask(self._source_resource.storage_url),
           ]],
-          messages=None)
+          messages=None,
+      )
