@@ -20,15 +20,18 @@ from typing import MutableMapping, MutableSequence
 import proto  # type: ignore
 
 from cloudsdk.google.protobuf import duration_pb2  # type: ignore
+from cloudsdk.google.protobuf import struct_pb2  # type: ignore
 from google.type import date_pb2  # type: ignore
 from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types import openapi
 from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types import tool
+from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types import vertex_rag_data
 
 
 __protobuf__ = proto.module(
     package='google.cloud.aiplatform.v1',
     manifest={
         'HarmCategory',
+        'Modality',
         'Content',
         'Part',
         'Blob',
@@ -37,12 +40,15 @@ __protobuf__ = proto.module(
         'PrebuiltVoiceConfig',
         'VoiceConfig',
         'SpeechConfig',
+        'ProactivityConfig',
         'GenerationConfig',
         'SafetySetting',
         'SafetyRating',
         'CitationMetadata',
         'Citation',
         'Candidate',
+        'UrlContextMetadata',
+        'UrlMetadata',
         'LogprobsResult',
         'Segment',
         'GroundingChunk',
@@ -50,6 +56,7 @@ __protobuf__ = proto.module(
         'GroundingMetadata',
         'SearchEntryPoint',
         'RetrievalMetadata',
+        'ModalityTokenCount',
     },
 )
 
@@ -70,7 +77,17 @@ class HarmCategory(proto.Enum):
             The harm category is sexually explicit
             content.
         HARM_CATEGORY_CIVIC_INTEGRITY (5):
-            The harm category is civic integrity.
+            Deprecated: Election filter is not longer
+            supported. The harm category is civic integrity.
+        HARM_CATEGORY_IMAGE_HATE (6):
+            The harm category is image hate.
+        HARM_CATEGORY_IMAGE_DANGEROUS_CONTENT (7):
+            The harm category is image dangerous content.
+        HARM_CATEGORY_IMAGE_HARASSMENT (8):
+            The harm category is image harassment.
+        HARM_CATEGORY_IMAGE_SEXUALLY_EXPLICIT (9):
+            The harm category is image sexually explicit
+            content.
     """
     HARM_CATEGORY_UNSPECIFIED = 0
     HARM_CATEGORY_HATE_SPEECH = 1
@@ -78,6 +95,35 @@ class HarmCategory(proto.Enum):
     HARM_CATEGORY_HARASSMENT = 3
     HARM_CATEGORY_SEXUALLY_EXPLICIT = 4
     HARM_CATEGORY_CIVIC_INTEGRITY = 5
+    HARM_CATEGORY_IMAGE_HATE = 6
+    HARM_CATEGORY_IMAGE_DANGEROUS_CONTENT = 7
+    HARM_CATEGORY_IMAGE_HARASSMENT = 8
+    HARM_CATEGORY_IMAGE_SEXUALLY_EXPLICIT = 9
+
+
+class Modality(proto.Enum):
+    r"""Content Part modality
+
+    Values:
+        MODALITY_UNSPECIFIED (0):
+            Unspecified modality.
+        TEXT (1):
+            Plain text.
+        IMAGE (2):
+            Image.
+        VIDEO (3):
+            Video.
+        AUDIO (4):
+            Audio.
+        DOCUMENT (5):
+            Document, e.g. PDF.
+    """
+    MODALITY_UNSPECIFIED = 0
+    TEXT = 1
+    IMAGE = 2
+    VIDEO = 3
+    AUDIO = 4
+    DOCUMENT = 5
 
 
 class Content(proto.Message):
@@ -156,6 +202,15 @@ class Part(proto.Message):
             containing any output from the function call. It is used as
             context to the model.
 
+            This field is a member of `oneof`_ ``data``.
+        executable_code (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.ExecutableCode):
+            Optional. Code generated by the model that is
+            meant to be executed.
+
+            This field is a member of `oneof`_ ``data``.
+        code_execution_result (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.CodeExecutionResult):
+            Optional. Result of executing the [ExecutableCode].
+
             This field is a member of `oneof`_ ``data``.
         video_metadata (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.VideoMetadata):
             Optional. Video metadata. The metadata should only be
@@ -163,6 +218,12 @@ class Part(proto.Message):
             or file_data.
 
             This field is a member of `oneof`_ ``metadata``.
+        thought (bool):
+            Optional. Indicates if the part is thought
+            from the model.
+        thought_signature (bytes):
+            Optional. An opaque signature for the thought
+            so it can be reused in subsequent requests.
     """
 
     text: str = proto.Field(
@@ -194,12 +255,32 @@ class Part(proto.Message):
         oneof='data',
         message=tool.FunctionResponse,
     )
+    executable_code: tool.ExecutableCode = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        oneof='data',
+        message=tool.ExecutableCode,
+    )
+    code_execution_result: tool.CodeExecutionResult = proto.Field(
+        proto.MESSAGE,
+        number=9,
+        oneof='data',
+        message=tool.CodeExecutionResult,
+    )
     video_metadata: 'VideoMetadata' = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof='metadata',
         message='VideoMetadata',
     )
+    thought: bool = proto.Field(
+        proto.BOOL,
+        number=10,
+    )
+    thought_signature: bytes = proto.Field(
+        proto.BYTES,
+        number=11,
+    )
 
 
 class Blob(proto.Message):
@@ -211,6 +292,16 @@ class Blob(proto.Message):
             source data.
         data (bytes):
             Required. Raw bytes.
+        display_name (str):
+            Optional. Display name of the blob.
+
+            Used to provide a label or filename to distinguish blobs.
+
+            This field is only returned in PromptMessage for prompt
+            management. It is currently used in the Gemini
+            GenerateContent calls only when server side tools
+            (code_execution, google_search, and url_context) are
+            enabled.
     """
 
     mime_type: str = proto.Field(
@@ -221,6 +312,10 @@ class Blob(proto.Message):
         proto.BYTES,
         number=2,
     )
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class FileData(proto.Message):
@@ -232,6 +327,17 @@ class FileData(proto.Message):
             source data.
         file_uri (str):
             Required. URI.
+        display_name (str):
+            Optional. Display name of the file data.
+
+            Used to provide a label or filename to distinguish file
+            datas.
+
+            This field is only returned in PromptMessage for prompt
+            management. It is currently used in the Gemini
+            GenerateContent calls only when server side tools
+            (code_execution, google_search, and url_context) are
+            enabled.
     """
 
     mime_type: str = proto.Field(
@@ -242,6 +348,10 @@ class FileData(proto.Message):
         proto.STRING,
         number=2,
     )
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class VideoMetadata(proto.Message):
@@ -312,6 +422,9 @@ class SpeechConfig(proto.Message):
     Attributes:
         voice_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.VoiceConfig):
             The configuration for the speaker to use.
+        language_code (str):
+            Optional. Language code (ISO 639. e.g. en-US)
+            for the speech synthesization.
     """
 
     voice_config: 'VoiceConfig' = proto.Field(
@@ -319,6 +432,33 @@ class SpeechConfig(proto.Message):
         number=1,
         message='VoiceConfig',
     )
+    language_code: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
+class ProactivityConfig(proto.Message):
+    r"""Config for proactivity features.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        proactive_audio (bool):
+            Optional. If enabled, the model can reject
+            responding to the last prompt. For example, this
+            allows the model to ignore out of context speech
+            or to stay silent if the user did not make a
+            request, yet.
+
+            This field is a member of `oneof`_ ``_proactive_audio``.
+    """
+
+    proactive_audio: bool = proto.Field(
+        proto.BOOL,
+        number=2,
+        optional=True,
+    )
 
 
 class GenerationConfig(proto.Message):
@@ -394,6 +534,49 @@ class GenerationConfig(proto.Message):
             response.
 
             This field is a member of `oneof`_ ``_response_schema``.
+        response_json_schema (google.protobuf.struct_pb2.Value):
+            Optional. Output schema of the generated response. This is
+            an alternative to ``response_schema`` that accepts `JSON
+            Schema <https://json-schema.org/>`__.
+
+            If set, ``response_schema`` must be omitted, but
+            ``response_mime_type`` is required.
+
+            While the full JSON Schema may be sent, not all features are
+            supported. Specifically, only the following properties are
+            supported:
+
+            -  ``$id``
+            -  ``$defs``
+            -  ``$ref``
+            -  ``$anchor``
+            -  ``type``
+            -  ``format``
+            -  ``title``
+            -  ``description``
+            -  ``enum`` (for strings and numbers)
+            -  ``items``
+            -  ``prefixItems``
+            -  ``minItems``
+            -  ``maxItems``
+            -  ``minimum``
+            -  ``maximum``
+            -  ``anyOf``
+            -  ``oneOf`` (interpreted the same as ``anyOf``)
+            -  ``properties``
+            -  ``additionalProperties``
+            -  ``required``
+
+            The non-standard ``propertyOrdering`` property may also be
+            set.
+
+            Cyclic references are unrolled to a limited degree and, as
+            such, may only be used within non-required properties.
+            (Nullable properties are not sufficient.) If ``$ref`` is set
+            on a sub-schema, no other properties, except for than those
+            starting as a ``$``, may be set.
+
+            This field is a member of `oneof`_ ``_response_json_schema``.
         routing_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.GenerationConfig.RoutingConfig):
             Optional. Routing configuration.
 
@@ -414,6 +597,15 @@ class GenerationConfig(proto.Message):
             Optional. The speech generation config.
 
             This field is a member of `oneof`_ ``_speech_config``.
+        thinking_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.GenerationConfig.ThinkingConfig):
+            Optional. Config for thinking features.
+            An error will be returned if this field is set
+            for models that don't support thinking.
+        enable_affective_dialog (bool):
+            Optional. If enabled, the model will detect
+            emotions and adapt its responses accordingly.
+
+            This field is a member of `oneof`_ ``_enable_affective_dialog``.
     """
     class Modality(proto.Enum):
         r"""The modalities of the response.
@@ -523,8 +715,9 @@ class GenerationConfig(proto.Message):
 
             Attributes:
                 model_name (str):
-                    The model name to use. Only the public LLM
-                    models are accepted. e.g. 'gemini-1.5-pro-001'.
+                    The model name to use. Only the public LLM models are
+                    accepted. See `Supported
+                    models <https://cloud.google.com/vertex-ai/generative-ai/docs/model-reference/inference#supported-models>`__.
 
                     This field is a member of `oneof`_ ``_model_name``.
             """
@@ -548,6 +741,36 @@ class GenerationConfig(proto.Message):
             message='GenerationConfig.RoutingConfig.ManualRoutingMode',
         )
 
+    class ThinkingConfig(proto.Message):
+        r"""Config for thinking features.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+        Attributes:
+            include_thoughts (bool):
+                Optional. Indicates whether to include
+                thoughts in the response. If true, thoughts are
+                returned only when available.
+
+                This field is a member of `oneof`_ ``_include_thoughts``.
+            thinking_budget (int):
+                Optional. Indicates the thinking budget in tokens. This is
+                only applied when enable_thinking is true.
+
+                This field is a member of `oneof`_ ``_thinking_budget``.
+        """
+
+        include_thoughts: bool = proto.Field(
+            proto.BOOL,
+            number=1,
+            optional=True,
+        )
+        thinking_budget: int = proto.Field(
+            proto.INT32,
+            number=3,
+            optional=True,
+        )
+
     temperature: float = proto.Field(
         proto.FLOAT,
         number=1,
@@ -612,6 +835,12 @@ class GenerationConfig(proto.Message):
         optional=True,
         message=openapi.Schema,
     )
+    response_json_schema: struct_pb2.Value = proto.Field(
+        proto.MESSAGE,
+        number=28,
+        optional=True,
+        message=struct_pb2.Value,
+    )
     routing_config: RoutingConfig = proto.Field(
         proto.MESSAGE,
         number=17,
@@ -640,6 +869,16 @@ class GenerationConfig(proto.Message):
         optional=True,
         message='SpeechConfig',
     )
+    thinking_config: ThinkingConfig = proto.Field(
+        proto.MESSAGE,
+        number=25,
+        message=ThinkingConfig,
+    )
+    enable_affective_dialog: bool = proto.Field(
+        proto.BOOL,
+        number=29,
+        optional=True,
+    )
 
 
 class SafetySetting(proto.Message):
@@ -734,6 +973,12 @@ class SafetyRating(proto.Message):
         blocked (bool):
             Output only. Indicates whether the content
             was filtered out because of this rating.
+        overwritten_threshold (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.SafetySetting.HarmBlockThreshold):
+            Output only. The overwritten threshold for
+            the safety category of Gemini 2.0 image out. If
+            minors are detected in the output image, the
+            threshold of each safety category will be
+            overwritten if user sets a lower threshold.
     """
     class HarmProbability(proto.Enum):
         r"""Harm probability levels in the content.
@@ -804,6 +1049,11 @@ class SafetyRating(proto.Message):
         proto.BOOL,
         number=3,
     )
+    overwritten_threshold: 'SafetySetting.HarmBlockThreshold' = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum='SafetySetting.HarmBlockThreshold',
+    )
 
 
 class CitationMetadata(proto.Message):
@@ -904,6 +1154,9 @@ class Candidate(proto.Message):
         grounding_metadata (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.GroundingMetadata):
             Output only. Metadata specifies sources used
             to ground generated content.
+        url_context_metadata (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.UrlContextMetadata):
+            Output only. Metadata related to url context
+            retrieval tool.
     """
     class FinishReason(proto.Enum):
         r"""The reason why the model stopped generating tokens.
@@ -942,6 +1195,20 @@ class Candidate(proto.Message):
             MALFORMED_FUNCTION_CALL (9):
                 The function call generated by the model is
                 invalid.
+            IMAGE_SAFETY (11):
+                Token generation stopped because generated
+                images has safety violations.
+            IMAGE_PROHIBITED_CONTENT (12):
+                Image generation stopped because generated
+                images has other prohibited content.
+            IMAGE_RECITATION (13):
+                Image generation stopped due to recitation.
+            IMAGE_OTHER (14):
+                Image generation stopped because of other
+                miscellaneous issue.
+            UNEXPECTED_TOOL_CALL (15):
+                The tool call generated by the model is
+                invalid.
         """
         FINISH_REASON_UNSPECIFIED = 0
         STOP = 1
@@ -953,6 +1220,11 @@ class Candidate(proto.Message):
         PROHIBITED_CONTENT = 7
         SPII = 8
         MALFORMED_FUNCTION_CALL = 9
+        IMAGE_SAFETY = 11
+        IMAGE_PROHIBITED_CONTENT = 12
+        IMAGE_RECITATION = 13
+        IMAGE_OTHER = 14
+        UNEXPECTED_TOOL_CALL = 15
 
     index: int = proto.Field(
         proto.INT32,
@@ -997,6 +1269,61 @@ class Candidate(proto.Message):
         number=7,
         message='GroundingMetadata',
     )
+    url_context_metadata: 'UrlContextMetadata' = proto.Field(
+        proto.MESSAGE,
+        number=13,
+        message='UrlContextMetadata',
+    )
+
+
+class UrlContextMetadata(proto.Message):
+    r"""Metadata related to url context retrieval tool.
+
+    Attributes:
+        url_metadata (MutableSequence[googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.UrlMetadata]):
+            Output only. List of url context.
+    """
+
+    url_metadata: MutableSequence['UrlMetadata'] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message='UrlMetadata',
+    )
+
+
+class UrlMetadata(proto.Message):
+    r"""Context of the a single url retrieval.
+
+    Attributes:
+        retrieved_url (str):
+            Retrieved url by the tool.
+        url_retrieval_status (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.UrlMetadata.UrlRetrievalStatus):
+            Status of the url retrieval.
+    """
+    class UrlRetrievalStatus(proto.Enum):
+        r"""Status of the url retrieval.
+
+        Values:
+            URL_RETRIEVAL_STATUS_UNSPECIFIED (0):
+                Default value. This value is unused.
+            URL_RETRIEVAL_STATUS_SUCCESS (1):
+                Url retrieval is successful.
+            URL_RETRIEVAL_STATUS_ERROR (2):
+                Url retrieval is failed due to error.
+        """
+        URL_RETRIEVAL_STATUS_UNSPECIFIED = 0
+        URL_RETRIEVAL_STATUS_SUCCESS = 1
+        URL_RETRIEVAL_STATUS_ERROR = 2
+
+    retrieved_url: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    url_retrieval_status: UrlRetrievalStatus = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=UrlRetrievalStatus,
+    )
 
 
 class LogprobsResult(proto.Message):
@@ -1147,6 +1474,10 @@ class GroundingChunk(proto.Message):
                 Title of the chunk.
 
                 This field is a member of `oneof`_ ``_title``.
+            domain (str):
+                Domain of the (original) URI.
+
+                This field is a member of `oneof`_ ``_domain``.
         """
 
         uri: str = proto.Field(
@@ -1159,6 +1490,11 @@ class GroundingChunk(proto.Message):
             number=2,
             optional=True,
         )
+        domain: str = proto.Field(
+            proto.STRING,
+            number=3,
+            optional=True,
+        )
 
     class RetrievedContext(proto.Message):
         r"""Chunk from context retrieved by the retrieval tools.
@@ -1166,6 +1502,12 @@ class GroundingChunk(proto.Message):
         .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
 
         Attributes:
+            rag_chunk (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.RagChunk):
+                Additional context for the RAG retrieval
+                result. This is only populated when using the
+                RAG retrieval tool.
+
+                This field is a member of `oneof`_ ``context_details``.
             uri (str):
                 URI reference of the attribution.
 
@@ -1180,6 +1522,12 @@ class GroundingChunk(proto.Message):
                 This field is a member of `oneof`_ ``_text``.
         """
 
+        rag_chunk: vertex_rag_data.RagChunk = proto.Field(
+            proto.MESSAGE,
+            number=4,
+            oneof='context_details',
+            message=vertex_rag_data.RagChunk,
+        )
         uri: str = proto.Field(
             proto.STRING,
             number=1,
@@ -1229,8 +1577,10 @@ class GroundingSupport(proto.Message):
             the claim.
         confidence_scores (MutableSequence[float]):
             Confidence score of the support references. Ranges from 0 to
-            1. 1 is the most confident. This list must have the same
-            size as the grounding_chunk_indices.
+            1. 1 is the most confident. For Gemini 2.0 and before, this
+            list must have the same size as the grounding_chunk_indices.
+            For Gemini 2.5 and after, this list will be empty and should
+            be ignored.
     """
 
     segment: 'Segment' = proto.Field(
@@ -1344,4 +1694,26 @@ class RetrievalMetadata(proto.Message):
     )
 
 
+class ModalityTokenCount(proto.Message):
+    r"""Represents token counting info for a single modality.
+
+    Attributes:
+        modality (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.Modality):
+            The modality associated with this token
+            count.
+        token_count (int):
+            Number of tokens.
+    """
+
+    modality: 'Modality' = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum='Modality',
+    )
+    token_count: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
