@@ -21,6 +21,8 @@ import proto  # type: ignore
 
 from cloudsdk.google.protobuf import struct_pb2  # type: ignore
 from google.type import latlng_pb2  # type: ignore
+from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import api_auth as gca_api_auth
+from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import auth
 from googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types import openapi
 
 
@@ -28,6 +30,7 @@ __protobuf__ = proto.module(
     package='google.cloud.aiplatform.v1beta1',
     manifest={
         'Tool',
+        'UrlContext',
         'ToolUseExample',
         'FunctionDeclaration',
         'FunctionCall',
@@ -37,7 +40,9 @@ __protobuf__ = proto.module(
         'Retrieval',
         'VertexRagStore',
         'VertexAISearch',
+        'ExternalApi',
         'GoogleSearchRetrieval',
+        'GoogleMaps',
         'EnterpriseWebSearch',
         'DynamicRetrievalConfig',
         'ToolConfig',
@@ -68,7 +73,7 @@ class Tool(proto.Message):
             [FunctionResponse][google.cloud.aiplatform.v1beta1.Part.function_response]
             for each function call in the next turn. Based on the
             function responses, Model will generate the final response
-            back to the user. Maximum 128 function declarations can be
+            back to the user. Maximum 512 function declarations can be
             provided.
         retrieval (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Retrieval):
             Optional. Retrieval tool type.
@@ -84,6 +89,9 @@ class Tool(proto.Message):
             Optional. GoogleSearchRetrieval tool type.
             Specialized retrieval tool that is powered by
             Google search.
+        google_maps (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.GoogleMaps):
+            Optional. GoogleMaps tool type.
+            Tool to support Google Maps in Model.
         enterprise_web_search (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.EnterpriseWebSearch):
             Optional. Tool to support searching public
             web data, powered by Vertex AI Search and Sec4
@@ -92,6 +100,14 @@ class Tool(proto.Message):
             Optional. CodeExecution tool type.
             Enables the model to execute code as part of
             generation.
+        url_context (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.UrlContext):
+            Optional. Tool to support URL context
+            retrieval.
+        computer_use (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Tool.ComputerUse):
+            Optional. Tool to support the model
+            interacting directly with the computer. If
+            enabled, it automatically populates computer-use
+            specific Function Declarations.
     """
 
     class GoogleSearch(proto.Message):
@@ -109,6 +125,32 @@ class Tool(proto.Message):
 
         """
 
+    class ComputerUse(proto.Message):
+        r"""Tool to support computer use.
+
+        Attributes:
+            environment (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Tool.ComputerUse.Environment):
+                Required. The environment being operated.
+        """
+        class Environment(proto.Enum):
+            r"""Represents the environment being operated, such as a web
+            browser.
+
+            Values:
+                ENVIRONMENT_UNSPECIFIED (0):
+                    Defaults to browser.
+                ENVIRONMENT_BROWSER (1):
+                    Operates in a web browser.
+            """
+            ENVIRONMENT_UNSPECIFIED = 0
+            ENVIRONMENT_BROWSER = 1
+
+        environment: 'Tool.ComputerUse.Environment' = proto.Field(
+            proto.ENUM,
+            number=1,
+            enum='Tool.ComputerUse.Environment',
+        )
+
     function_declarations: MutableSequence['FunctionDeclaration'] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
@@ -129,6 +171,11 @@ class Tool(proto.Message):
         number=3,
         message='GoogleSearchRetrieval',
     )
+    google_maps: 'GoogleMaps' = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message='GoogleMaps',
+    )
     enterprise_web_search: 'EnterpriseWebSearch' = proto.Field(
         proto.MESSAGE,
         number=6,
@@ -139,6 +186,21 @@ class Tool(proto.Message):
         number=4,
         message=CodeExecution,
     )
+    url_context: 'UrlContext' = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message='UrlContext',
+    )
+    computer_use: ComputerUse = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        message=ComputerUse,
+    )
+
+
+class UrlContext(proto.Message):
+    r"""Tool to support URL context.
+    """
 
 
 class ToolUseExample(proto.Message):
@@ -271,12 +333,37 @@ class FunctionDeclaration(proto.Message):
             required:
 
              - param1
+        parameters_json_schema (google.protobuf.struct_pb2.Value):
+            Optional. Describes the parameters to the function in JSON
+            Schema format. The schema must describe an object where the
+            properties are the parameters to the function. For example:
+
+            ::
+
+               {
+                 "type": "object",
+                 "properties": {
+                   "name": { "type": "string" },
+                   "age": { "type": "integer" }
+                 },
+                 "additionalProperties": false,
+                 "required": ["name", "age"],
+                 "propertyOrdering": ["name", "age"]
+               }
+
+            This field is mutually exclusive with ``parameters``.
         response (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Schema):
             Optional. Describes the output from this
             function in JSON Schema format. Reflects the
             Open API 3.03 Response Object. The Schema
             defines the type used for the response value of
             the function.
+        response_json_schema (google.protobuf.struct_pb2.Value):
+            Optional. Describes the output from this function in JSON
+            Schema format. The value specified by the schema is the
+            response value of the function.
+
+            This field is mutually exclusive with ``response``.
     """
 
     name: str = proto.Field(
@@ -292,11 +379,21 @@ class FunctionDeclaration(proto.Message):
         number=3,
         message=openapi.Schema,
     )
+    parameters_json_schema: struct_pb2.Value = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=struct_pb2.Value,
+    )
     response: openapi.Schema = proto.Field(
         proto.MESSAGE,
         number=4,
         message=openapi.Schema,
     )
+    response_json_schema: struct_pb2.Value = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=struct_pb2.Value,
+    )
 
 
 class FunctionCall(proto.Message):
@@ -305,15 +402,23 @@ class FunctionCall(proto.Message):
     JSON object containing the parameters and their values.
 
     Attributes:
+        id (str):
+            Optional. The unique id of the function call. If populated,
+            the client to execute the ``function_call`` and return the
+            response with the matching ``id``.
         name (str):
             Required. The name of the function to call. Matches
             [FunctionDeclaration.name].
         args (google.protobuf.struct_pb2.Struct):
-            Optional. Required. The function parameters and values in
-            JSON object format. See [FunctionDeclaration.parameters] for
-            parameter details.
+            Optional. The function parameters and values in JSON object
+            format. See [FunctionDeclaration.parameters] for parameter
+            details.
     """
 
+    id: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     name: str = proto.Field(
         proto.STRING,
         number=1,
@@ -333,6 +438,10 @@ class FunctionResponse(proto.Message):
     based on model prediction.
 
     Attributes:
+        id (str):
+            Optional. The id of the function call this response is for.
+            Populated by the client to match the corresponding function
+            call ``id``.
         name (str):
             Required. The name of the function to call. Matches
             [FunctionDeclaration.name] and [FunctionCall.name].
@@ -345,6 +454,10 @@ class FunctionResponse(proto.Message):
             treated as function output.
     """
 
+    id: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     name: str = proto.Field(
         proto.STRING,
         number=1,
@@ -360,8 +473,9 @@ class ExecutableCode(proto.Message):
     r"""Code generated by the model that is meant to be executed, and the
     result returned to the model.
 
-    Generated when using the [FunctionDeclaration] tool and
-    [FunctionCallingConfig] mode is set to [Mode.CODE].
+    Generated when using the [CodeExecution] tool, in which the code
+    will be automatically executed, and a corresponding
+    [CodeExecutionResult] will also be generated.
 
     Attributes:
         language (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExecutableCode.Language):
@@ -397,7 +511,8 @@ class ExecutableCode(proto.Message):
 class CodeExecutionResult(proto.Message):
     r"""Result of executing the [ExecutableCode].
 
-    Always follows a ``part`` containing the [ExecutableCode].
+    Only generated when using the [CodeExecution] tool, and always
+    follows a ``part`` containing the [ExecutableCode].
 
     Attributes:
         outcome (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.CodeExecutionResult.Outcome):
@@ -462,6 +577,11 @@ class Retrieval(proto.Message):
             store. User data is uploaded via the
             VertexRagDataService.
 
+            This field is a member of `oneof`_ ``source``.
+        external_api (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi):
+            Use data source powered by external API for
+            grounding.
+
             This field is a member of `oneof`_ ``source``.
         disable_attribution (bool):
             Optional. Deprecated. This option is no
@@ -480,6 +600,12 @@ class Retrieval(proto.Message):
         oneof='source',
         message='VertexRagStore',
     )
+    external_api: 'ExternalApi' = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof='source',
+        message='ExternalApi',
+    )
     disable_attribution: bool = proto.Field(
         proto.BOOL,
         number=3,
@@ -513,6 +639,15 @@ class VertexRagStore(proto.Message):
         rag_retrieval_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.RagRetrievalConfig):
             Optional. The retrieval config for the Rag
             query.
+        store_context (bool):
+            Optional. Currently only supported for Gemini Multimodal
+            Live API.
+
+            In Gemini Multimodal Live API, if ``store_context`` bool is
+            specified, Gemini will leverage it to automatically memorize
+            the interactions between the client and Gemini, and retrieve
+            context when needed to augment the response generation for
+            users' ongoing and future interactions.
     """
 
     class RagResource(proto.Message):
@@ -560,6 +695,10 @@ class VertexRagStore(proto.Message):
         number=6,
         message='RagRetrievalConfig',
     )
+    store_context: bool = proto.Field(
+        proto.BOOL,
+        number=7,
+    )
 
 
 class VertexAISearch(proto.Message):
@@ -576,8 +715,48 @@ class VertexAISearch(proto.Message):
             Optional. Fully-qualified Vertex AI Search engine resource
             ID. Format:
             ``projects/{project}/locations/{location}/collections/{collection}/engines/{engine}``
+        max_results (int):
+            Optional. Number of search results to return
+            per query. The default value is 10.
+            The maximumm allowed value is 10.
+        filter (str):
+            Optional. Filter strings to be passed to the
+            search API.
+        data_store_specs (MutableSequence[googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.VertexAISearch.DataStoreSpec]):
+            Specifications that define the specific
+            DataStores to be searched, along with
+            configurations for those data stores. This is
+            only considered for Engines with multiple data
+            stores.
+            It should only be set if engine is used.
     """
 
+    class DataStoreSpec(proto.Message):
+        r"""Define data stores within engine to filter on in a search
+        call and configurations for those data stores. For more
+        information, see
+        https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec
+
+        Attributes:
+            data_store (str):
+                Full resource name of DataStore, such as Format:
+                ``projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}``
+            filter (str):
+                Optional. Filter specification to filter documents in the
+                data store specified by data_store field. For more
+                information on filtering, see
+                `Filtering <https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata>`__
+        """
+
+        data_store: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        filter: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+
     datastore: str = proto.Field(
         proto.STRING,
         number=1,
@@ -586,6 +765,135 @@ class VertexAISearch(proto.Message):
         proto.STRING,
         number=2,
     )
+    max_results: int = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    data_store_specs: MutableSequence[DataStoreSpec] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=DataStoreSpec,
+    )
+
+
+class ExternalApi(proto.Message):
+    r"""Retrieve from data source powered by external API for
+    grounding. The external API is not owned by Google, but need to
+    follow the pre-defined API spec.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        simple_search_params (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi.SimpleSearchParams):
+            Parameters for the simple search API.
+
+            This field is a member of `oneof`_ ``params``.
+        elastic_search_params (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi.ElasticSearchParams):
+            Parameters for the elastic search API.
+
+            This field is a member of `oneof`_ ``params``.
+        api_spec (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ExternalApi.ApiSpec):
+            The API spec that the external API
+            implements.
+        endpoint (str):
+            The endpoint of the external API. The system
+            will call the API at this endpoint to retrieve
+            the data for grounding. Example:
+            https://acme.com:443/search
+        api_auth (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ApiAuth):
+            The authentication config to access the API. Deprecated.
+            Please use auth_config instead.
+        auth_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.AuthConfig):
+            The authentication config to access the API.
+    """
+    class ApiSpec(proto.Enum):
+        r"""The API spec that the external API implements.
+
+        Values:
+            API_SPEC_UNSPECIFIED (0):
+                Unspecified API spec. This value should not
+                be used.
+            SIMPLE_SEARCH (1):
+                Simple search API spec.
+            ELASTIC_SEARCH (2):
+                Elastic search API spec.
+        """
+        API_SPEC_UNSPECIFIED = 0
+        SIMPLE_SEARCH = 1
+        ELASTIC_SEARCH = 2
+
+    class SimpleSearchParams(proto.Message):
+        r"""The search parameters to use for SIMPLE_SEARCH spec.
+        """
+
+    class ElasticSearchParams(proto.Message):
+        r"""The search parameters to use for the ELASTIC_SEARCH spec.
+
+        Attributes:
+            index (str):
+                The ElasticSearch index to use.
+            search_template (str):
+                The ElasticSearch search template to use.
+            num_hits (int):
+                Optional. Number of hits (chunks) to request.
+
+                When specified, it is passed to Elasticsearch as the
+                ``num_hits`` param.
+        """
+
+        index: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        search_template: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        num_hits: int = proto.Field(
+            proto.INT32,
+            number=6,
+        )
+
+    simple_search_params: SimpleSearchParams = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        oneof='params',
+        message=SimpleSearchParams,
+    )
+    elastic_search_params: ElasticSearchParams = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        oneof='params',
+        message=ElasticSearchParams,
+    )
+    api_spec: ApiSpec = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=ApiSpec,
+    )
+    endpoint: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    api_auth: gca_api_auth.ApiAuth = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=gca_api_auth.ApiAuth,
+    )
+    auth_config: auth.AuthConfig = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=auth.AuthConfig,
+    )
 
 
 class GoogleSearchRetrieval(proto.Message):
@@ -605,6 +913,31 @@ class GoogleSearchRetrieval(proto.Message):
     )
 
 
+class GoogleMaps(proto.Message):
+    r"""Tool to retrieve public maps data for grounding, powered by
+    Google.
+
+    Attributes:
+        api_auth (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ApiAuth):
+            The authentication config to access the API. Deprecated.
+            Please use auth_config instead.
+        auth_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.AuthConfig):
+            The authentication config to access the API.
+            Only API key is supported.
+    """
+
+    api_auth: gca_api_auth.ApiAuth = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_api_auth.ApiAuth,
+    )
+    auth_config: auth.AuthConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=auth.AuthConfig,
+    )
+
+
 class EnterpriseWebSearch(proto.Message):
     r"""Tool to search public web data, powered by Vertex AI Search
     and Sec4 compliance.
@@ -878,8 +1211,8 @@ class RagRetrievalConfig(proto.Message):
 
             Attributes:
                 model_name (str):
-                    Optional. The model name used for ranking. Format:
-                    ``gemini-1.5-pro``
+                    Optional. The model name used for ranking. See `Supported
+                    models <https://cloud.google.com/vertex-ai/generative-ai/docs/model-reference/inference#supported-models>`__.
 
                     This field is a member of `oneof`_ ``_model_name``.
             """
