@@ -13,7 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""The service projects command group for the App Hub CLI."""
+"""The operations command group for the App Hub CLI."""
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
@@ -23,6 +23,7 @@ from googlecloudsdk.calliope import base
 # NOTE: Release track decorators can be used here as well, and would propagate
 # to this group's children.
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.UniverseCompatible
 class OperationsGA(base.Group):
   """Manage App Hub Operations (long-running operations).
 
@@ -31,6 +32,7 @@ class OperationsGA(base.Group):
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.UniverseCompatible
 class OperationsAlpha(base.Group):
   """Manage App Hub Operations (long-running operations).
 
