@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2016 Google Inc. All Rights Reserved.
+# Copyright 2016 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+import textwrap
+
 from googlecloudsdk.api_lib.bigtable import util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.bigtable import arguments
@@ -27,10 +29,20 @@ from googlecloudsdk.core.console import console_io
 class DeleteInstance(base.DeleteCommand):
   """Delete an existing Bigtable instance."""
 
+  detailed_help = {
+      'EXAMPLES':
+          textwrap.dedent("""\
+          To delete an instance, run:
+
+            $ {command} my-instance-id
+
+          """),
+  }
+
   @staticmethod
   def Args(parser):
     """Register flags for this command."""
-    arguments.ArgAdder(parser).AddInstance(multiple=True)
+    arguments.AddInstancesResourceArg(parser, 'to delete', positional=True)
     parser.display_info.AddCacheUpdater(arguments.InstanceCompleter)
 
   def Run(self, args):
