@@ -20,7 +20,9 @@ from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.run import connection_context
+from googlecloudsdk.command_lib.run import deletion
 from googlecloudsdk.command_lib.run import flags
+from googlecloudsdk.command_lib.run import pretty_print
 from googlecloudsdk.command_lib.run import resource_args
 from googlecloudsdk.command_lib.run import serverless_operations
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
@@ -29,15 +31,18 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core.console import console_io
 
 
+@base.UniverseCompatible
 @base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class Delete(base.Command):
   """Delete a revision."""
 
   detailed_help = {
-      'DESCRIPTION': """\
+      'DESCRIPTION':
+          """\
           {description}
           """,
-      'EXAMPLES': """\
+      'EXAMPLES':
+          """\
           To delete a revision:
 
               $ {command} <revision-name>
@@ -53,6 +58,7 @@ class Delete(base.Command):
         required=True,
         prefixes=False)
     concept_parsers.ConceptParser([revision_presentation]).AddToParser(parser)
+    flags.AddAsyncFlag(parser, default_async_for_cluster=True)
 
   @staticmethod
   def Args(parser):
@@ -61,7 +67,7 @@ class Delete(base.Command):
   def Run(self, args):
     """Delete a revision."""
     conn_context = connection_context.GetConnectionContext(
-        args, product=flags.Product.RUN)
+        args, flags.Product.RUN, self.ReleaseTrack())
     revision_ref = args.CONCEPTS.revision.Parse()
 
     console_io.PromptContinue(
@@ -70,9 +76,17 @@ class Delete(base.Command):
         throw_if_unattended=True,
         cancel_on_no=True)
 
+    async_ = deletion.AsyncOrDefault(args.async_)
     with serverless_operations.Connect(conn_context) as client:
-      client.DeleteRevision(revision_ref)
-    log.DeletedResource(revision_ref.revisionsId, 'revision')
+      deletion.Delete(
+          revision_ref, client.GetRevision, client.DeleteRevision, async_
+      )
+    if async_:
+      pretty_print.Success(
+          'Revision [{}] is being deleted.'.format(revision_ref.revisionsId)
+      )
+    else:
+      log.DeletedResource(revision_ref.revisionsId, 'revision')
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -83,4 +97,5 @@ class AlphaDelete(Delete):
   def Args(parser):
     Delete.CommonArgs(parser)
 
+
 AlphaDelete.__doc__ = Delete.__doc__
