@@ -44,12 +44,11 @@ Container Flags
     If the --container or --remove-containers flag is specified the following
     arguments may only be specified after a --container flag.
     """
-  del release_track  # Unused.
   group = base.ArgumentGroup(help=help_text)
   group.AddArgument(flags.ImageArg(required=False))
   group.AddArgument(flags.PortArg())
   group.AddArgument(flags.Http2Flag())
-  group.AddArgument(flags.MutexEnvVarsFlags())
+  group.AddArgument(flags.MutexEnvVarsFlags(release_track=release_track))
   group.AddArgument(flags.MemoryFlag())
   group.AddArgument(flags.CpuFlag())
   group.AddArgument(flags.CommandFlag())
@@ -62,7 +61,7 @@ Container Flags
   group.AddArgument(flags.ClearVolumeMountsFlag())
   group.AddArgument(flags.StartupProbeFlag())
   group.AddArgument(flags.LivenessProbeFlag())
-  group.AddArgument(flags.GpuFlag(hidden=False))
+  group.AddArgument(flags.GpuFlag())
 
   return group
 
@@ -98,10 +97,11 @@ class Update(base.Command):
     flags.AddCmekKeyRevocationActionTypeFlag(parser)
     flags.AddCpuThrottlingFlag(parser)
     flags.AddCustomAudiencesFlag(parser)
+    flags.AddDefaultUrlFlag(parser)
     flags.AddEgressSettingsFlag(parser)
     flags.AddEncryptionKeyShutdownHoursFlag(parser)
-    flags.AddGpuTypeFlag(parser, hidden=False)
-    flags.GpuZonalRedundancyFlag(parser, hidden=False)
+    flags.AddGpuTypeFlag(parser)
+    flags.GpuZonalRedundancyFlag(parser)
     flags.AddRevisionSuffixArg(parser)
     flags.AddSandboxArg(parser)
     flags.AddSessionAffinityFlag(parser)
@@ -297,11 +297,11 @@ class BetaUpdate(Update):
     cls.CommonArgs(parser)
 
     # Flags specific to managed CR
-    flags.AddDefaultUrlFlag(parser)
     flags.AddDeployHealthCheckFlag(parser)
     flags.AddScalingFlag(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.AddIapFlag(parser)
+    flags.AddServiceMaxInstancesFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_parser.AddContainerFlags(parser, container_args)
 
@@ -321,7 +321,6 @@ class AlphaUpdate(BetaUpdate):
 
     # Flags specific to managed CR
     flags.AddDeployHealthCheckFlag(parser)
-    flags.AddDefaultUrlFlag(parser)
     flags.AddIapFlag(parser)
     flags.AddRuntimeFlag(parser)
     flags.AddDescriptionFlag(parser)
@@ -335,6 +334,7 @@ class AlphaUpdate(BetaUpdate):
     flags.MESH_DATAPLANE_FLAG.AddToParser(parser)
     flags.AddOverflowScalingFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
+    container_args.AddArgument(flags.ReadinessProbeFlag())
     container_parser.AddContainerFlags(parser, container_args)
 
 
