@@ -10,7 +10,7 @@ import logging
 import os
 import sys
 import time
-from typing import Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 import uuid
 
 # To configure apiclient logging.
@@ -326,6 +326,7 @@ def DeleteJob(
       raise
 
 
+
 #################################
 ## Job control
 #################################
@@ -1011,10 +1012,11 @@ def RunQueryRpc(
               statistics=dict(
                   query=dict(
                       totalBytesProcessed=result['totalBytesProcessed'],
-                      cacheHit=result['cacheHit'],
                   )
               )
           )
+          if 'cacheHit' in result:
+            execution['statistics']['query']['cacheHit'] = result['cacheHit']
           if 'schema' in result:
             execution['statistics']['query']['schema'] = result['schema']
           return ([], [], execution)
